@@ -80,6 +80,8 @@ function _aws_cdk_aws_memorydb_CfnUserProps(p) {
 }
 function _aws_cdk_aws_memorydb_CfnUser(p) {
 }
+function _aws_cdk_aws_memorydb_CfnUser_AuthenticationModeProperty(p) {
+}
 function print(name, deprecationMessage) {
     const deprecated = process.env.JSII_DEPRECATED;
     const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
@@ -116,4 +118,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_memorydb_CfnACLProps, _aws_cdk_aws_memorydb_CfnACL, _aws_cdk_aws_memorydb_CfnClusterProps, _aws_cdk_aws_memorydb_CfnCluster, _aws_cdk_aws_memorydb_CfnCluster_EndpointProperty, _aws_cdk_aws_memorydb_CfnParameterGroupProps, _aws_cdk_aws_memorydb_CfnParameterGroup, _aws_cdk_aws_memorydb_CfnSubnetGroupProps, _aws_cdk_aws_memorydb_CfnSubnetGroup, _aws_cdk_aws_memorydb_CfnUserProps, _aws_cdk_aws_memorydb_CfnUser };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_memorydb_CfnACLProps, _aws_cdk_aws_memorydb_CfnACL, _aws_cdk_aws_memorydb_CfnClusterProps, _aws_cdk_aws_memorydb_CfnCluster, _aws_cdk_aws_memorydb_CfnCluster_EndpointProperty, _aws_cdk_aws_memorydb_CfnParameterGroupProps, _aws_cdk_aws_memorydb_CfnParameterGroup, _aws_cdk_aws_memorydb_CfnSubnetGroupProps, _aws_cdk_aws_memorydb_CfnSubnetGroup, _aws_cdk_aws_memorydb_CfnUserProps, _aws_cdk_aws_memorydb_CfnUser, _aws_cdk_aws_memorydb_CfnUser_AuthenticationModeProperty };
